==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cognito/kotlin/inputs/RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cognito.kotlin.inputs

import com.pulumi.aws.cognito.inputs.RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventAction The action to take in response to the account takeover action. Valid values are `BLOCK`, `MFA_IF_CONFIGURED`, `MFA_REQUIRED` and `NO_ACTION`.
 * @property notify Whether to send a notification.
 */
public data class RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs(
    public val eventAction: Output<String>,
    public val notify: Output<Boolean>,
) :
    ConvertibleToJava<com.pulumi.aws.cognito.inputs.RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs> {
    override fun toJava():
        com.pulumi.aws.cognito.inputs.RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs =
        com.pulumi.aws.cognito.inputs.RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs.builder()
            .eventAction(eventAction.applyValue({ args0 -> args0 }))
            .notify_(notify.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs].
 */
@PulumiTagMarker
public class RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgsBuilder
internal constructor() {
    private var eventAction: Output<String>? = null

    private var notify: Output<Boolean>? = null

    /**
     * @param value The action to take in response to the account takeover action. Valid values are `BLOCK`, `MFA_IF_CONFIGURED`, `MFA_REQUIRED` and `NO_ACTION`.
     */
    @JvmName("gwdmtbmigwxdhbak")
    public suspend fun eventAction(`value`: Output<String>) {
        this.eventAction = value
    }

    /**
     * @param value Whether to send a notification.
     */
    @JvmName("bnikidkxaopalyau")
    public suspend fun notify(`value`: Output<Boolean>) {
        this.notify = value
    }

    /**
     * @param value The action to take in response to the account takeover action. Valid values are `BLOCK`, `MFA_IF_CONFIGURED`, `MFA_REQUIRED` and `NO_ACTION`.
     */
    @JvmName("diuoguvptpkoianx")
    public suspend fun eventAction(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventAction = mapped
    }

    /**
     * @param value Whether to send a notification.
     */
    @JvmName("gwwoadtgbqqqgcoc")
    public suspend fun notify(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notify = mapped
    }

    internal fun build(): RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs =
        RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs(
            eventAction = eventAction ?: throw PulumiNullFieldException("eventAction"),
            notify = notify ?: throw PulumiNullFieldException("notify"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cognito/kotlin/inputs/RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cognito.kotlin.inputs

import com.pulumi.aws.cognito.inputs.RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventAction
 * @property notify Whether to send a notification.
 */
public data class RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs(
    public val eventAction: Output<String>,
    public val notify: Output<Boolean>,
) :
    ConvertibleToJava<com.pulumi.aws.cognito.inputs.RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs> {
    override fun toJava(): com.pulumi.aws.cognito.inputs.RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs =
        com.pulumi.aws.cognito.inputs.RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs.builder()
            .eventAction(eventAction.applyValue({ args0 -> args0 }))
            .notify_(notify.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs].
 */
@PulumiTagMarker
public class RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgsBuilder
internal constructor() {
    private var eventAction: Output<String>? = null

    private var notify: Output<Boolean>? = null

    /**
     * @param value
     */
    @JvmName("arhkeggubvqvkdvs")
    public suspend fun eventAction(`value`: Output<String>) {
        this.eventAction = value
    }

    /**
     * @param value Whether to send a notification.
     */
    @JvmName("kwbqrabftlglxgde")
    public suspend fun notify(`value`: Output<Boolean>) {
        this.notify = value
    }

    /**
     * @param value
     */
    @JvmName("lpljdkeggimpfgrf")
    public suspend fun eventAction(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventAction = mapped
    }

    /**
     * @param value Whether to send a notification.
     */
    @JvmName("kdftjbfxkjvxjkmt")
    public suspend fun notify(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notify = mapped
    }

    internal fun build(): RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs =
        RiskConfigurationAccountTakeoverRiskConfigurationActionsMediumActionArgs(
            eventAction = eventAction ?: throw PulumiNullFieldException("eventAction"),
            notify = notify ?: throw PulumiNullFieldException("notify"),
        )
}
